## pa_trim is a dataframe, with locations as rows and taxa as columns.  values in cells are 1s (presence) and 0s (absence). The rownames are ideally some location identifier and the column names must be the taxon names.
## traits_trim is a dataframe, with taxa as rows and traits as columns. values in cells are the trait values for each taxon.  The rownames must be the taxon names, and must match the column names in the pa_trim dataframe.

calcEcometricMean_df <- function(pa_trim, traits_trim){
  
  # create ecometric mean for each trait ----
  
  # for each location, pull out all species present in the cell.
  # omit locations with no taxa
  pa_trim <- pa_trim[-which(rowSums(pa_trim)==0),]
  spList <- apply(pa_trim, 1, function(x) which(x>0)) # pull out species presences 
  
  findRows <- lapply(spList, function(x) match(names(x), rownames(traits_trim))) # find the rows of those species in the traits df
  
  # create warning flag
  if (any(is.na(findRows))){
    print("WARNING: Some species did not match!!")
  }
  
  # Then pull out the values associated with each trait
  ecoDF <- lapply(findRows, function(x) traits_trim[x,])
  
  # calculate ecometric mean for all traits for each location
  ecoMean <- lapply(ecoDF, function(x) colMeans(x, na.rm=T))
  nSpecies <- lapply(findRows, function(x) length(x)) #save info on species richness
  
  # create dataframes/vectors
  ecoMean_df <- matrix(unlist(ecoMean), ncol = ncol(traits_trim), byrow = TRUE)
  rownames(ecoMean_df) <- names(ecoMean)
  nSpecies_v <- unlist(nSpecies)
  names(nSpecies_v) <- names(ecoMean)
  
  #return(list(ecoMean_df, nSpecies_v))
  x <- list(ecoMean_df, nSpecies_v)
  names(x) <- c("ecoMean_df", "nSpecies_v")
  return(x) #returns two objects in a list: the ecometric mean for each lcoation and the number of species in that location.
}